@@ -23,9 +23,15 @@ FAILEDOPERATION_CANCELJOBFAILURE = 'FailedOperation.CancelJobFailure'
 # 未检测到人脸。
 FAILEDOPERATION_DETECTNOFACE = 'FailedOperation.DetectNoFace'
 
+# 人脸检测失败。
+FAILEDOPERATION_FACEDETECTFAILED = 'FailedOperation.FaceDetectFailed'
+
 # 人脸出框，无法使用。
 FAILEDOPERATION_FACEEXCEEDBORDER = 'FailedOperation.FaceExceedBorder'
 
+# 人脸配准失败。
+FAILEDOPERATION_FACESHAPEFAILED = 'FailedOperation.FaceShapeFailed'
+
 # 人脸因太小被过滤，建议人脸分辨率不小于34*34。
 FAILEDOPERATION_FACESIZETOOSMALL = 'FailedOperation.FaceSizeTooSmall'
 
@@ -65,6 +71,9 @@ FAILEDOPERATION_JOBNOTEXIST = 'FailedOperation.JobNotExist'
 # 任务已停止处理，请重新提交任务。
 FAILEDOPERATION_JOBSTOPPROCESSING = 'FailedOperation.JobStopProcessing'
 
+# FailedOperation.ParameterValueError
+FAILEDOPERATION_PARAMETERVALUEERROR = 'FailedOperation.ParameterValueError'
+
 # 整个请求体太大（通常主要是图片）。
 FAILEDOPERATION_REQUESTENTITYTOOLARGE = 'FailedOperation.RequestEntityTooLarge'
 
@@ -74,6 +83,12 @@ FAILEDOPERATION_REQUESTTIMEOUT = 'FailedOperation.RequestTimeout'
 # RPC请求失败，一般为算法微服务故障。
 FAILEDOPERATION_RPCFAIL = 'FailedOperation.RpcFail'
 
+# 任务不存在。
+FAILEDOPERATION_TASKNOTEXIST = 'FailedOperation.TaskNotExist'
+
+# 未知错误。
+FAILEDOPERATION_UNKNOWN = 'FailedOperation.Unknown'
+
 # 内部错误。
 INTERNALERROR = 'InternalError'
 
@@ -101,6 +116,9 @@ INVALIDPARAMETERVALUE_IMAGEEMPTY = 'InvalidParameterValue.ImageEmpty'
 # 图片数据太大。
 INVALIDPARAMETERVALUE_IMAGESIZEEXCEED = 'InvalidParameterValue.ImageSizeExceed'
 
+# 图片尺寸不对。
+INVALIDPARAMETERVALUE_LUTIMAGESIZEINVALID = 'InvalidParameterValue.LutImageSizeInvalid'
+
 # 图片中没有人脸。
 INVALIDPARAMETERVALUE_NOFACEINPHOTO = 'InvalidParameterValue.NoFaceInPhoto'
 
@@ -113,13 +131,13 @@ INVALIDPARAMETERVALUE_URLILLEGAL = 'InvalidParameterValue.UrlIllegal'
 # 资源正在发货中。
 RESOURCEUNAVAILABLE_DELIVERING = 'ResourceUnavailable.Delivering'
 
-# 帐号已被冻结。
+# 账号已被冻结。
 RESOURCEUNAVAILABLE_FREEZE = 'ResourceUnavailable.Freeze'
 
 # 获取认证信息失败。
 RESOURCEUNAVAILABLE_GETAUTHINFOERROR = 'ResourceUnavailable.GetAuthInfoError'
 
-# 帐号已欠费。
+# 账号已欠费。
 RESOURCEUNAVAILABLE_INARREARS = 'ResourceUnavailable.InArrears'
 
 # 余额不足。
@@ -134,13 +152,13 @@ RESOURCEUNAVAILABLE_NOTREADY = 'ResourceUnavailable.NotReady'
 # 资源已被回收。
 RESOURCEUNAVAILABLE_RECOVER = 'ResourceUnavailable.Recover'
 
-# 帐号已停服。
+# 账号已停服。
 RESOURCEUNAVAILABLE_STOPUSING = 'ResourceUnavailable.StopUsing'
 
 # 计费状态未知。
 RESOURCEUNAVAILABLE_UNKNOWNSTATUS = 'ResourceUnavailable.UnknownStatus'
 
-# 帐号已欠费。
+# 账号已欠费。
 RESOURCESSOLDOUT_CHARGESTATUSEXCEPTION = 'ResourcesSoldOut.ChargeStatusException'
 
 # 未知方法名。
